<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCrossSections</name>
    <message>
      <location filename="../../Command.cpp" line="269"/>
      <source>MeshPart</source>
      <translation>Mallat</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="270"/>
      <source>Cross-sections...</source>
      <translation>Interseccions...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Cross-sections</source>
      <translation>Interseccions</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="305"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="306"/>
      <source>Curve on mesh...</source>
      <translation>Corba en malla...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="307"/>
      <source>Creates an approximated curve on top of a mesh.
This command only works with a 'mesh' object.</source>
      <translation>Crea una corba aproximada damunt d'una malla.
Aquesta comanda només funciona amb objectes 'malla'.</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="59"/>
      <source>Create mesh from shape...</source>
      <translation>Crea una malla a partir d'una forma...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Tessellate shape</source>
      <translation>Tesel·la la forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location filename="../../Command.cpp" line="185"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="186"/>
      <source>Create section from mesh and plane</source>
      <translation>Crea una secció a partir d'una malla i un pla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="187"/>
      <source>Section</source>
      <translation>Secció</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Trim mesh with a plane</source>
      <translation>Retalla la malla amb un pla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="85"/>
      <location filename="../../Command.cpp" line="86"/>
      <source>Trims a mesh with a plane</source>
      <translation>Retalla una malla amb un pla</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Trim with plane</source>
      <translation>Retalla amb el pla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Section with plane</source>
      <translation>Secció amb un pla</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CrossSections</name>
    <message>
      <location filename="../../CrossSections.ui" line="14"/>
      <source>Cross sections</source>
      <translation>Seccions transversals</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="20"/>
      <source>Guiding plane</source>
      <translation>Guiant plànol</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="26"/>
      <source>XY</source>
      <translation>XY</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="36"/>
      <source>XZ</source>
      <translation>XZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="43"/>
      <source>YZ</source>
      <translation>YZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="52"/>
      <source>Position:</source>
      <translation>Posició:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="71"/>
      <source>Sections</source>
      <translation>Seccions</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="83"/>
      <source>On both sides</source>
      <translation>En tots dos costats</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="92"/>
      <source>Count</source>
      <translation>Comptar</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="109"/>
      <source>Distance:</source>
      <translation>Distància:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="128"/>
      <source>Options</source>
      <translation>Opcions</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="134"/>
      <source>Connect edges if distance less than</source>
      <translation>Connecta les arestes si la distància és menor que</translation>
    </message>
    <message>
      <location filename="../../CrossSections.cpp" line="366"/>
      <source>Failure</source>
      <translation>Fallada</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="364"/>
      <source>Create</source>
      <translation>Crea</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="366"/>
      <source>Close wire</source>
      <translation>Tanca el filferro</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="368"/>
      <source>Clear</source>
      <translation>Neteja</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="369"/>
      <source>Cancel</source>
      <translation>Cancel·la</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="615"/>
      <source>Wrong mesh picked</source>
      <translation>S'ha seleccionat una malla incorrecta</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="655"/>
      <source>No point was picked</source>
      <translation>No s'ha seleccionat cap punt.</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="14"/>
      <source>Curve on mesh</source>
      <translation>Corba en malla</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="23"/>
      <source>Press 'Start', then pick points on the mesh; when enough points have been set, right-click and choose 'Create'. Repeat this process to create more splines. Close this task panel to complete the operation.

This command only works with a 'mesh' object, not a regular face or surface. To convert an object to a mesh use the tools of the Mesh Workbench.</source>
      <translation>Premeu 'Inicia', després trieu punts de la malla. Quan hagueu triat prou punts, cliqueu amb el botó dret i escolliu 'Crea'. Repetiu aquest procés per crear més splines. Tanqueu aquest panell de tasques per completar l'operació.

Aquesta ordre només funciona amb objectes 'malla', no amb cares o superfícies normals. Per convertir un objecte en malla, feu servir les eines del banc de treball Malla.</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="38"/>
      <source>Wire</source>
      <translation>Cable</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="44"/>
      <source>Snap tolerance to vertices</source>
      <translation>Tolerància de l'ajust als vèrtexs</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="51"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="61"/>
      <source>Split threshold</source>
      <translation>Llindar de divisió</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="87"/>
      <source>Spline Approximation</source>
      <translation>Aproximació d'spline</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="96"/>
      <source>Tolerance to mesh</source>
      <translation>Tolerància de malla</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="122"/>
      <source>Continuity</source>
      <translation>Continuitat</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="136"/>
      <source>Maximum curve degree</source>
      <translation>Grau màxim de la corba</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="153"/>
      <source>Start</source>
      <translation>Inicia</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="14"/>
      <source>Tessellation</source>
      <translation>Tessel·lació</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="20"/>
      <source>Meshing options</source>
      <translation>Opcions de mallat</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="30"/>
      <source>Standard</source>
      <translation>Estàndard</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="33"/>
      <source>Use the standard mesher</source>
      <translation>Utilitza el generador de malles estàndard</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="41"/>
      <source>Surface deviation:</source>
      <translation>Desviació de superfície:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="48"/>
      <source>Maximal linear deflection of a mesh section from the surface of the object</source>
      <translation>Deflexió lineal màxima d’una secció de malla des de la superfície de l’objecte</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="67"/>
      <source>Angular deviation:</source>
      <translation>Desviació angular:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="74"/>
      <source>Maximal angular deflection of a mesh section to the next section</source>
      <translation>Deflexió angular màxima d’una secció de malla a la secció següent</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="98"/>
      <source>The maximal linear deviation of a mesh segment will be the specified
Surface deviation multiplied by the length of the current mesh segment (edge)</source>
      <translation>La desviació lineal màxima d'un segment de malla serà la desviació de les superfícies especificada multiplicada per la longitud del segment de malla actual (aresta)</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="102"/>
      <source>Relative surface deviation</source>
      <translation>Desviació de superfície relativa</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="109"/>
      <source>Mesh will get face colors of the object</source>
      <translation>La malla obtindrà els colors de les cares de l’objecte</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="112"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplica els colors de les cares a la malla</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="119"/>
      <source>Mesh segments will be grouped according to the color of the object faces.
These groups will be exported for mesh output formats supporting
this feature (e.g. the format OBJ).</source>
      <translation>Els segments de malla s'agruparan segons el color de les cares de l'objecte. Aquests grups s'exportaran per als formats d'eixida de la malla que admeten aquesta funció (p. ex., el format OBJ).</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="124"/>
      <source>Define segments by face colors</source>
      <translation>Defineix segments pels colors de les cares</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="145"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="148"/>
      <source>Use the Mefisto mesher</source>
      <translation>Utilitza el generador de malles Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="156"/>
      <source>Maximum edge length:</source>
      <translation>Longitud màxima de l'aresta:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="162"/>
      <source>If this number is smaller the mesh becomes finer.
The smallest value is 0.</source>
      <translation>Si aquest nombre és més petit, la malla es torna més fina. El valor més petit és 0.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="183"/>
      <source>Estimate</source>
      <translation>Estimació</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="206"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="209"/>
      <source>Use the Netgen mesher</source>
      <translation>Utilitza el generador de malles Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="217"/>
      <source>Fineness:</source>
      <translation>Precisió:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="234"/>
      <source>Very coarse</source>
      <translation>Molt gruixuda</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="239"/>
      <source>Coarse</source>
      <translation>Gruixuda</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="244"/>
      <source>Moderate</source>
      <translation>Moderada</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="249"/>
      <source>Fine</source>
      <translation>Fina</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="254"/>
      <source>Very fine</source>
      <translation>Molt fina</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="259"/>
      <source>User defined</source>
      <translation>Definida per l'usuari</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="269"/>
      <source>Mesh size grading:</source>
      <translation>Gradació de la mida de malla:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="279"/>
      <source>If this parameter is smaller, the mesh becomes finer.
A value in the range of 0.1-1.</source>
      <translation>Si aquest paràmetre és més petit, la malla es torna més fina. Un valor en l’interval entre 0.1-1.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="302"/>
      <source>Elements per edge:</source>
      <translation>Elements per aresta:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="312"/>
      <location filename="../../Tessellation.ui" line="345"/>
      <source>If this parameter is larger, the mesh becomes finer.
A value in the range of 0.2-10.</source>
      <translation>Si aquest paràmetre és més gran la malla es torna més fina. Un valor en l’interval entre 0.2-10.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="335"/>
      <source>Elements per curvature radius:</source>
      <translation>Elements per radi de curvatura:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="370"/>
      <source>Whether optimization of surface shape will be done</source>
      <translation>Indica si es realitzarà l'optimització de la forma de la superfície</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="373"/>
      <source>Optimize surface</source>
      <translation>Optimitza la superfície</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="383"/>
      <source>Whether second order elements will be generated</source>
      <translation>Indica si es generaran elements de segon ordre</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="386"/>
      <source>Second order elements</source>
      <translation>Elements de segon ordre</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="393"/>
      <source>Whether meshes will be arranged preferably using quadrilateral faces</source>
      <translation>Indica si les malles estaran disposades utilitzant preferentment cares de quadrilàters</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="396"/>
      <source>Quad dominated</source>
      <translation>Predomini de quadrilàters</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="422"/>
      <source>Leave panel open</source>
      <translation>Deixa el tauler obert</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="61"/>
      <source>Gmsh</source>
      <translation>Gmsh</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="225"/>
      <location filename="../../Tessellation.cpp" line="231"/>
      <source>No active document</source>
      <translation>Document no Actiu</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="259"/>
      <source>You have selected a body without tip.
Either set the tip of the body or select a different shape, please.</source>
      <translation>Heu seleccionat un cos sense punta
Posa la punta del cos o selecciona una forma diferent, si us plau.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="263"/>
      <source>You have selected a shape without faces.
Select a different shape, please.</source>
      <translation>Heu seleccionat una forma sense cares.
Seleccioneu una forma diferent, si us plau.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="267"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Seleccioneu primer una forma per al mallat</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="198"/>
      <source>Select plane</source>
      <translation>Seleccioneu un pla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Seleccioneu un pla a partir del qual seccionat la malla</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="95"/>
      <source>Select plane</source>
      <translation>Seleccioneu un pla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="96"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Seleccioneu un pla al qual ajustar la malla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Trim by plane</source>
      <translation>Divideix pel pla</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Select the side you want to keep.</source>
      <translation>Seleccioneu la cara que voleu conservar.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Below</source>
      <translation>Davall</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Above</source>
      <translation>Damunt</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Split</source>
      <translation>Dividir</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>MeshPart</source>
      <translation>Mallat</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatMesh</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="47"/>
      <source>Unwrap Mesh</source>
      <translation>Desembolica la malla</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="50"/>
      <source>Find a flat representation of a mesh.</source>
      <translation>Trobeu una representació plana d'una malla.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatFace</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="79"/>
      <source>Unwrap Face</source>
      <translation>Desembolica la cara</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="82"/>
      <source>Find a flat representation of a face.</source>
      <translation>Trobeu una representació plana d'una malla.</translation>
    </message>
  </context>
</TS>
